@@ -6,13 +6,13 @@ class GlueStatement:
     CANCELLING = "CANCELLING"
     AVAILABLE = "AVAILABLE"
     CANCELLED = "CANCELLED"
+    TIMEOUT = "TIMEOUT"
     ERROR = "ERROR"
 
-    def __init__(self, client, session_id, code, timeout):
+    def __init__(self, client, session_id, code):
         self.client = client
         self.code = code
         self.session_id = session_id
-        self.timeout = timeout
         self._statement_id = None
 
     def _run_statement(self):
@@ -32,10 +32,8 @@ class GlueStatement:
     def execute(self):
         self._run_statement()
         for elasped in wait(1):
-            if elasped > self.timeout:
-                raise TimeoutError
             response = self._get_statement()
             state = response.get("Statement", {}).get("State", GlueStatement.WAITING)
-            if state in [GlueStatement.AVAILABLE, GlueStatement.ERROR,GlueStatement.CANCELLING, GlueStatement.WAITING]:
+            if state in [GlueStatement.AVAILABLE, GlueStatement.ERROR,GlueStatement.CANCELLING, GlueStatement.WAITING, GlueStatement.TIMEOUT]:
                 break
         return response
