@@ -1,6 +1,8 @@
 {% macro get_insert_overwrite_sql(source_relation, target_relation) %}
     {%- set dest_columns = adapter.get_columns_in_relation(target_relation) -%}
     {%- set dest_cols_csv = dest_columns | map(attribute='name') | join(', ') -%}
+    set hive.exec.dynamic.partition.mode=nonstrict
+    dbt_next_query
     insert overwrite table {{ target_relation }}
     {{ partition_cols(label="partition") }}
     select {{dest_cols_csv}} from {{ source_relation }}
